@@ -7,9 +7,10 @@
 @ Gitee : https://gitee.com/ZeroSeeker
 """
 import easydownload
-import numpy as np
+# import numpy as np
 import platform
 import datetime
+import ddddocr
 import shutil
 import cv2
 import os
@@ -129,7 +130,60 @@ def proc_slider(
     if alpha_white_max is None:
         cv2.imwrite(proc_file_dir, image_gray)  # 存储灰度图
     else:
+        # 这里处理后的图，是一个透明背景的全黑缺口图，需要在边缘加一圈白色像素点，方便识别
+        # 扫描边界内1个像素距离内的所有像素点，如果像素是不透明的黑色点，对这个像素点的4临近8个点都扫描，看是否有透明点，如果有透明点，将这些点变成白色，否则忽略
+        white_points = list()
+        for each_height_proc in range(1, height-1):
+            for each_weight_proc in range(1, weight-1):
+                point_0 = image_unchanged[each_height_proc, each_weight_proc]  # 像素自身
+                if point_0[3] == 255:
+                    # 不透明点
+                    point_1 = image_unchanged[each_height_proc - 1, each_weight_proc - 1]  # 左上角
+                    if point_1[3] == 0:
+                        if [each_height_proc - 1, each_weight_proc - 1] not in white_points:
+                            white_points.append([each_height_proc - 1, each_weight_proc - 1])
+
+                    point_2 = image_unchanged[each_height_proc - 1, each_weight_proc]  # 上方
+                    if point_2[3] == 0:
+                        if [each_height_proc - 1, each_weight_proc] not in white_points:
+                            white_points.append([each_height_proc - 1, each_weight_proc])
+
+                    point_3 = image_unchanged[each_height_proc - 1, each_weight_proc + 1]  # 右上角
+                    if point_3[3] == 0:
+                        if [each_height_proc - 1, each_weight_proc + 1] not in white_points:
+                            white_points.append([each_height_proc - 1, each_weight_proc + 1])
+
+                    point_4 = image_unchanged[each_height_proc, each_weight_proc + 1]  # 右方
+                    if point_4[3] == 0:
+                        if [each_height_proc, each_weight_proc + 1] not in white_points:
+                            white_points.append([each_height_proc, each_weight_proc + 1])
+
+                    point_5 = image_unchanged[each_height_proc + 1, each_weight_proc + 1]  # 右下角
+                    if point_5[3] == 0:
+                        if [each_height_proc + 1, each_weight_proc + 1] not in white_points:
+                            white_points.append([each_height_proc + 1, each_weight_proc + 1])
+
+                    point_6 = image_unchanged[each_height_proc + 1, each_weight_proc]  # 下方
+                    if point_6[3] == 0:
+                        if [each_height_proc + 1, each_weight_proc] not in white_points:
+                            white_points.append([each_height_proc + 1, each_weight_proc])
+
+                    point_7 = image_unchanged[each_height_proc + 1, each_weight_proc - 1]  # 左下角
+                    if point_7[3] == 0:
+                        if [each_height_proc + 1, each_weight_proc - 1] not in white_points:
+                            white_points.append([each_height_proc + 1, each_weight_proc - 1])
+
+                    point_8 = image_unchanged[each_height_proc, each_weight_proc - 1]  # 左方
+                    if point_8[3] == 0:
+                        if [each_height_proc, each_weight_proc - 1] not in white_points:
+                            white_points.append([each_height_proc, each_weight_proc - 1])
+                else:
+                    # 透明点
+                    pass
+        for each_white_point in white_points:
+            image_unchanged[each_white_point[0], each_white_point[1]] = [255, 255, 255, 255]
         cv2.imwrite(proc_file_dir, image_unchanged)
+
     return proc_file_dir
 
 
@@ -173,56 +227,70 @@ def identify_gap_locations(
             path=save_path
         )['file_dir']  # 下载滑块图
 
-    background_proc_dir = proc_background(
-        image_dir=background_dir
-    )  # 处理背景图片
-    slider_proc_dir = proc_slider(
-        image_dir=slider_dir,
-        alpha_white_max=proc_slider_alpha_white_max
-    )  # 处理滑块图片
+    # background_proc_dir = proc_background(
+    #     image_dir=background_dir
+    # )  # 处理背景图片
+    # slider_proc_dir = proc_slider(
+    #     image_dir=slider_dir,
+    #     alpha_white_max=proc_slider_alpha_white_max
+    # )  # 处理滑块图片
 
     # 获取尺寸
     background_w, background_h = cv2.imread(
-        filename=background_proc_dir,
+        filename=background_dir,
         flags=0
     ).shape[::-1]  # 背景图尺寸
-    # print(background_w, background_h)
+    # # print(background_w, background_h)
     slider_w, slider_h = cv2.imread(
-        filename=slider_proc_dir,
+        filename=slider_dir,
         flags=0
     ).shape[::-1]  # 滑块尺寸
-    # print(slider_w, slider_h)
+    # # print(slider_w, slider_h)
+    #
+    # background_proc = cv2.imread(
+    #     filename=background_proc_dir
+    # )
+    # slider_proc = cv2.imread(
+    #     filename=slider_proc_dir
+    # )
+    slide = ddddocr.DdddOcr(det=False, ocr=False)
 
-    background_proc = cv2.imread(
-        filename=background_proc_dir
-    )
-    slider_proc = cv2.imread(
-        filename=slider_proc_dir
-    )
+    with open(slider_dir, 'rb') as f:
+        target_bytes = f.read()
 
-    result = cv2.matchTemplate(
-        slider_proc,
-        background_proc,
-        cv2.TM_CCOEFF_NORMED
-    )
-    identify_h, identify_w = np.unravel_index(
-        result.argmax(),
-        result.shape
-    )
+    with open(background_dir, 'rb') as f:
+        background_bytes = f.read()
 
-    cv2.rectangle(
-        background_proc,
-        (identify_w, identify_h),
-        (identify_w + slider_w, identify_h + slider_h),
-        (7, 249, 151),
-        2
-    )  # 展示圈出来的区域
+    res = slide.slide_match(target_bytes, background_bytes, simple_target=True)
+    print(res)
+    res_target = res['target']
+    identify_h = res_target[1]
+    identify_w = res_target[0]
 
-    recognition = save_path + path_separator + 'recognition.jpg'
-    cv2.imwrite(
-        recognition,
-        background_proc
-    )
+
+    # result = cv2.matchTemplate(
+    #     slider_proc,
+    #     background_proc,
+    #     cv2.TM_CCOEFF_NORMED
+    # )
+    # identify_h, identify_w = np.unravel_index(
+    #     result.argmax(),
+    #     result.shape
+    # )
+    #
+    # cv2.rectangle(
+    #     background_proc,
+    #     (identify_w, identify_h),
+    #     (identify_w + slider_w, identify_h + slider_h),
+    #     (7, 249, 151),
+    #     2
+    # )  # 展示圈出来的区域
+    #
+    # recognition = save_path + path_separator + 'recognition.jpg'
+    # cv2.imwrite(
+    #     recognition,
+    #     background_proc
+    # )
     # show(template)
     if retain is True:
         pass
